This test is carried out by retrieving two random 16S sequences from NCBI.

The database is located at:

https://www.ncbi.nlm.nih.gov/refseq/targetedloci/16S_process/

The `generate.py` script automatically creates the input FASTA files by using these two accession numbers:

* `NR_171545.1`
* `NR_171544.1`

The correct classifications are the following:

*  Bacteria; Actinobacteria; Micrococcales; Micrococcaceae; Kocuria.
*  Bacteria; Actinobacteria; Propionibacteriales; Nocardioidaceae; Marmoricola.